@@ -2,9 +2,15 @@
 #include "yapp.h"
 #include "ysocket.h"
 #include "debug.h"
+#include "intl.h"
 
 #include <stdio.h>
 #include <string.h>
+#include <netinet/in.h>
+#include <sys/socket.h>
+
+static YApplication *app;
+char const *ApplicationName = "iceskt";
 
 class SockTest: public YSocketListener {
 public:
@@ -19,30 +25,29 @@ public:
         sk.connect((struct sockaddr *) &in, sizeof(in));
     }
     virtual ~SockTest() {
-        sk.close();
     }
 
     virtual void socketConnected() {
-        puts("Connected");
+        MSG("Connected\n");
 
         const char *s = "GET / HTTP/1.0\r\n\r\n";
 
-        sk.write((unsigned char *)s, strlen(s));
-        puts("Written");
-        sk.read(bf, sizeof(bf));
+        sk.write(s, strlen(s));
+        MSG("Written");
+        sk.read((char *) bf, sizeof(bf));
     }
 
     virtual void socketError(int err) {
-        if (err) printf("error: %d\n", err);
-        else puts("EOF");
+        if (err) warn(_("Socket error: %d"), err);
+        else { MSG("EOF\n"); }
         app->exit(err ? 1 : 0);
     }
 
-    virtual void socketDataRead(unsigned char *buf, int len) {
-        printf("read %d\n", len);
+    virtual void socketDataRead(char *buf, int len) {
+        msg("read %d\n", len);
         if (len > 0) {
             //write(1, buf, len);
-            sk.read(bf, sizeof(bf));
+            sk.read((char *) bf, sizeof(bf));
         }
     }
 private:
@@ -51,8 +56,15 @@ private:
 };
 
 int main(int argc, char **argv) {
+
+    bindtextdomain(PACKAGE, LOCDIR);
+    textdomain(PACKAGE);
+
     YApplication app(&argc, &argv);
+    ::app = &app;
 
     SockTest sk;
     return app.mainLoop();
 }
+
+// vim: set sw=4 ts=4 et:
