@@ -20,9 +20,6 @@
 #include <wctype.h>
 #endif
 
-#define utf8ellipsis "\xe2\x80\xa6"
-const unsigned utf32ellipsis = 0x2026;
-
 static inline Display* display()  { return xapp->display(); }
 
 /******************************************************************************/
@@ -290,6 +287,12 @@ void Graphics::drawString(int x, int y, char const * str) {
         fFont->drawGlyphs(*this, x, y, str, int(strlen(str)));
 }
 
+void Graphics::drawChars(wchar_t* data, int offset, int len, int x, int y)
+{
+    if (fFont != null)
+        fFont->drawGlyphs(*this, x, y, data + offset, len);
+}
+
 /**
  * Draw a string but limit its width. If overlong, truncate and show optional
  * ... character.
@@ -573,7 +576,7 @@ void Graphics::drawPixmap(ref<YPixmap> pix, int sx, int sy,
     Picture source = pix->picture(), destin = picture();
     if (source && destin) {
         XRenderComposite(display(), PictOpOver, source, None, destin,
-                         0, 0, 0, 0, dx - xOrigin, dy - yOrigin, w, h);
+                         sx, sy, 0, 0, dx - xOrigin, dy - yOrigin, w, h);
         return;
     }
 
@@ -655,7 +658,7 @@ void Graphics::compositeImage(ref<YImage> img, int sx, int sy, unsigned w, unsig
             XRenderComposite(display(),
                              img->hasAlpha() ? PictOpOver : PictOpSrc,
                              source, None, picture(),
-                             0, 0, 0, 0, rx, ry,
+                             sx, sy, 0, 0, rx, ry,
                              unsigned(rw), unsigned(rh));
             return;
         }
@@ -956,6 +959,18 @@ void Graphics::drawSurface(YSurface const & surface, int x, int y, unsigned w, u
     }
 }
 
+void Graphics::drawSurface(const YSurface& surf, int x, int y, unsigned w, unsigned h)
+{
+    if (surf.gradient != null)
+        drawGradient(surf.gradient, x, y, w, h);
+    else if (surf.pixmap != null)
+        fillPixmap(surf.pixmap, x, y, w, h);
+    else if (surf.color) {
+        setColor(surf.color);
+        fillRect(x, y, w, h);
+    }
+}
+
 void Graphics::drawGradient(ref<YImage> gradient,
                             int x, int y, unsigned w, unsigned h,
                             int gx, int gy, unsigned gw, unsigned gh)
@@ -965,6 +980,14 @@ void Graphics::drawGradient(ref<YImage> gradient,
         scaled->draw(*this, gx, gy, w, h, x, y);
 }
 
+void Graphics::drawGradient(ref<YImage> gradient,
+                            int x, int y, unsigned w, unsigned h)
+{
+    ref<YImage> scaled = gradient->scale(w, h);
+    if (scaled != null)
+        scaled->draw(*this, 0, 0, w, h, x, y);
+}
+
 /******************************************************************************/
 
 void Graphics::drawArrow(YDirection direction, int x, int y, unsigned size,
